@@ -31,7 +31,7 @@ class TestTelemetryIntegration(manager.ScenarioTest):
     def skip_checks(cls):
         super(TestTelemetryIntegration, cls).skip_checks()
         for name in ["aodh", "gnocchi", "nova", "heat",
-                     "panko", "ceilometer", "glance"]:
+                     "ceilometer", "glance"]:
             cls._check_service(name)
 
     @classmethod
@@ -91,7 +91,6 @@ class TestTelemetryIntegration(manager.ScenarioTest):
             "AODH_GRANULARITY": str(config.CONF.telemetry.alarm_granularity),
             "AODH_SERVICE_URL": self._get_endpoint(auth, "alarming_plugin"),
             "GNOCCHI_SERVICE_URL": self._get_endpoint(auth, "metric"),
-            "PANKO_SERVICE_URL": self._get_endpoint(auth, "event"),
             "HEAT_SERVICE_URL": self._get_endpoint(auth, "heat_plugin"),
             "NOVA_SERVICE_URL": self._get_endpoint(auth, "compute"),
             "GLANCE_SERVICE_URL": self._get_endpoint(auth, "image"),
